@@ -227,55 +227,6 @@ class ActivityService:
         """
         return self.__client.call("eleme.activity.marketing.queryOrderSubsidy", {"orderId": order_id})
 
-    def create_campaign_dy_channel(self, request):
-        """
-        抖音创建招商活动后调用，创建e侧抖音频道
-        :param request:创建e侧抖音频道
-        """
-        return self.__client.call("eleme.activity.dy.createCampaignDyChannel", {"request": request})
-
-    def audit_status_call_back(self, request):
-        """
-        抖音审核状态回调
-        :param request:抖音审核状态回调
-        """
-        return self.__client.call("eleme.activity.dy.auditStatusCallBack", {"request": request})
-
-    def query_ele_apply_status(self, request):
-        """
-        抖音查询e侧报名单状态，用于核对状态一致性
-        :param request:查询e侧报名单状态
-        """
-        return self.__client.call("eleme.activity.dy.queryEleApplyStatus", {"request": request})
-
-    def offline_sku_apply(self, request):
-        """
-        抖音侧商品退出报名时调用，e侧商品退出报名
-        :param request:商品退出报名
-        """
-        return self.__client.call("eleme.activity.dy.offlineSkuApply", {"request": request})
-
-    def create_coupon_activity(self, request):
-        """
-        抖音侧创建券活动时调用
-        :param request:抖音创建券活动
-        """
-        return self.__client.call("eleme.activity.dy.createCouponActivity", {"request": request})
-
-    def modify_coupon_activity(self, request):
-        """
-        抖音侧修改券活动时调用
-        :param request:抖音创建券活动
-        """
-        return self.__client.call("eleme.activity.dy.modifyCouponActivity", {"request": request})
-
-    def query_dy_coupon_activity(self, request):
-        """
-        根据dy券活动id查询券活动信息
-        :param request:抖音查询券活动信息
-        """
-        return self.__client.call("eleme.activity.dy.queryDyCouponActivity", {"request": request})
-
     def create_and_participate_chain_price_activity(self, activity, chain_id, shop_apply_info):
         """
         创建并绑定连锁店特价活动
