@@ -46,6 +46,55 @@ class ProductService:
         """
         return self.__client.call("eleme.product.chain.menu.deleteMenu", {"mid": mid})
 
+    def list_by_shop_id(self, shop_id):
+        """
+        查询店铺下的所有有效渠道商品
+        :param shopId:店铺id
+        """
+        return self.__client.call("eleme.product.channel.item.listByShopId", {"shopId": shop_id})
+
+    def list_by_item_ids(self, item_ids):
+        """
+        根据商品id批量查询商品信息
+        :param itemIds:批量商品id列表
+        """
+        return self.__client.call("eleme.product.channel.item.listByItemIds", {"itemIds": item_ids})
+
+    def create(self, item):
+        """
+        创建渠道商品
+        :param item:创建商品模型
+        """
+        return self.__client.call("eleme.product.channel.item.create", {"item": item})
+
+    def modify(self, item):
+        """
+        更新渠道商品
+        :param item:更新商品模型
+        """
+        return self.__client.call("eleme.product.channel.item.modify", {"item": item})
+
+    def remove(self, item_id):
+        """
+        删除渠道商品
+        :param itemId:商品Id
+        """
+        return self.__client.call("eleme.product.channel.item.remove", {"itemId": item_id})
+
+    def batch_set_sale_status(self, item_sale_status_map):
+        """
+        批量设置售卖状态
+        :param itemSaleStatusMap:商品id和对应的售卖状态集合
+        """
+        return self.__client.call("eleme.product.channel.item.batchSetSaleStatus", {"itemSaleStatusMap": item_sale_status_map})
+
+    def batch_set_stock(self, sku_stock_map):
+        """
+        批量设置库存
+        :param skuStockMap:规格id和对应的库存值
+        """
+        return self.__client.call("eleme.product.channel.item.batchSetStock", {"skuStockMap": sku_stock_map})
+
     def get_group(self, gid):
         """
         查询连锁总店商品分组
@@ -265,6 +314,28 @@ class ProductService:
         """
         return self.__client.call("eleme.product.category.removeDayPartingStickTime", {"shopId": shop_id, "categoryId": category_id})
 
+    def get_back_category_v_2(self, shop_id):
+        """
+        查询新版商品后台类目
+        :param shopId:店铺Id
+        """
+        return self.__client.call("eleme.product.category.getBackCategoryV2", {"shopId": shop_id})
+
+    def get_back_category_property_v_2(self, shop_id, back_category_id):
+        """
+        查询新版商品后台类目属性
+        :param shopId:店铺Id
+        :param backCategoryId:后台类目id
+        """
+        return self.__client.call("eleme.product.category.getBackCategoryPropertyV2", {"shopId": shop_id, "backCategoryId": back_category_id})
+
+    def get_materials(self, shop_id):
+        """
+        查询新版商品原材料
+        :param shopId:店铺Id
+        """
+        return self.__client.call("eleme.product.category.getMaterials", {"shopId": shop_id})
+
     def create_package(self, category_id, o_package):
         """
         添加套餐
@@ -351,6 +422,13 @@ class ProductService:
         """
         return self.__client.call("eleme.product.item.updateItem", {"itemId": item_id, "categoryId": category_id, "properties": properties})
 
+    def batch_update_items(self, requests):
+        """
+        批量更新商品
+        :param requests:批量更新请求
+        """
+        return self.__client.call("eleme.product.item.batchUpdateItems", {"requests": requests})
+
     def batch_fill_stock(self, spec_ids):
         """
         批量置满库存
@@ -365,6 +443,14 @@ class ProductService:
         """
         return self.__client.call("eleme.product.item.batchClearStock", {"specIds": spec_ids})
 
+    def batch_update_stock_detail(self, shop_id, update_stock_requests):
+        """
+        批量修改库存详细信息
+        :param shopId:店铺Id
+        :param updateStockRequests:更新规格请求列表
+        """
+        return self.__client.call("eleme.product.item.batchUpdateStockDetail", {"shopId": shop_id, "updateStockRequests": update_stock_requests})
+
     def batch_on_shelf(self, spec_ids):
         """
         批量上架商品
@@ -572,6 +658,13 @@ class ProductService:
         """
         return self.__client.call("eleme.product.item.updateMultiSpecItem", {"itemId": item_id, "categoryId": category_id, "properties": properties})
 
+    def batch_update_multi_spec_item(self, requests):
+        """
+        批量更新多规格商品
+        :param requests:商品规格
+        """
+        return self.__client.call("eleme.product.item.batchUpdateMultiSpecItem", {"requests": requests})
+
     def set_ingredient_group(self, item_id, group_relations):
         """
         设置配料组数据
@@ -580,6 +673,14 @@ class ProductService:
         """
         return self.__client.call("eleme.product.item.setIngredientGroup", {"itemId": item_id, "groupRelations": group_relations})
 
+    def set_sku_ingredient_group(self, spec_id, group_relations):
+        """
+        设置配料组数据
+        :param specId:商品Id
+        :param groupRelations:配料组信息
+        """
+        return self.__client.call("eleme.product.item.setSkuIngredientGroup", {"specId": spec_id, "groupRelations": group_relations})
+
     def remove_ingredient_group(self, item_id):
         """
         删除配料组数据
@@ -589,7 +690,7 @@ class ProductService:
 
     def get_item_material_tree(self, shop_id):
         """
-        获取商品原材料数据(新版)
+        获取商品原材料数据（即将下线）
         :param shopId:店铺ID
         """
         return self.__client.call("eleme.product.item.getItemMaterialTree", {"shopId": shop_id})
@@ -637,6 +738,14 @@ class ProductService:
         """
         return self.__client.call("eleme.product.item.bindIngredientGroups", {"itemId": item_id, "ingredientGroupIds": ingredient_group_ids})
 
+    def bind_sku_ingredient_groups(self, spec_id, ingredient_group_ids):
+        """
+        给主料商品绑定配料组（规格维度）
+        :param specId:主料商品规格id
+        :param ingredientGroupIds:配料组id列表
+        """
+        return self.__client.call("eleme.product.item.bindSkuIngredientGroups", {"specId": spec_id, "ingredientGroupIds": ingredient_group_ids})
+
     def unbind_ingredient_groups(self, item_id, ingredient_group_ids):
         """
         解绑配料组
@@ -645,6 +754,14 @@ class ProductService:
         """
         return self.__client.call("eleme.product.item.unbindIngredientGroups", {"itemId": item_id, "ingredientGroupIds": ingredient_group_ids})
 
+    def unbind_sku_ingredient_groups(self, spec_id, ingredient_group_ids):
+        """
+        解绑配料组（规格维度）
+        :param specId:主料商品规格id
+        :param ingredientGroupIds:配料组id列表
+        """
+        return self.__client.call("eleme.product.item.unbindSkuIngredientGroups", {"specId": spec_id, "ingredientGroupIds": ingredient_group_ids})
+
     def remove_main_item_ingredient_groups(self, item_id):
         """
         移除主料商品的全部配料组
@@ -652,6 +769,13 @@ class ProductService:
         """
         return self.__client.call("eleme.product.item.removeMainItemIngredientGroups", {"itemId": item_id})
 
+    def remove_sku_ingredient_groups(self, spec_id):
+        """
+        移除主料商品的全部配料组（规格维度）
+        :param specId:主料商品规格id
+        """
+        return self.__client.call("eleme.product.item.removeSkuIngredientGroups", {"specId": spec_id})
+
     def update_item_group(self, shop_id, item_id, category_id):
         """
         更新单店商品所属分组
@@ -661,6 +785,86 @@ class ProductService:
         """
         return self.__client.call("eleme.product.item.updateItemGroup", {"shopId": shop_id, "itemId": item_id, "categoryId": category_id})
 
+    def bind_video(self, item_id, content_id):
+        """
+        绑定商品视频
+        :param itemId:商品id
+        :param contentId:内容id
+        """
+        return self.__client.call("eleme.product.item.bindVideo", {"itemId": item_id, "contentId": content_id})
+
+    def unbind_video(self, item_id):
+        """
+        解绑商品视频
+        :param itemId:商品id
+        """
+        return self.__client.call("eleme.product.item.unbindVideo", {"itemId": item_id})
+
+    def get_items_by_category_id_v_2(self, category_id):
+        """
+        获取一个分类下的所有商品V2接口
+        :param categoryId:商品分类Id
+        """
+        return self.__client.call("eleme.product.item.getItemsByCategoryIdV2", {"categoryId": category_id})
+
+    def batch_update_shop_items(self, shop_id, request):
+        """
+        批量更新商品信息
+        :param shopId:店铺id
+        :param request:店铺商品信息
+        """
+        return self.__client.call("eleme.product.item.batchUpdateShopItems", {"shopId": shop_id, "request": request})
+
+    def batch_update_item_ingredient(self, shop_id, request):
+        """
+        批量更新商品配料信息
+        :param shopId:店铺id
+        :param request:店铺商品信息
+        """
+        return self.__client.call("eleme.product.item.batchUpdateItemIngredient", {"shopId": shop_id, "request": request})
+
+    def batch_update_item_category(self, shop_id, request):
+        """
+        批量更新商品类目、类目属性、主材料信息
+        :param shopId:店铺id
+        :param request:店铺商品信息
+        """
+        return self.__client.call("eleme.product.item.batchUpdateItemCategory", {"shopId": shop_id, "request": request})
+
+    def get_shop_limited_items(self, shop_id):
+        """
+        获取店铺内修改受限制的商品，包含两类商品：有锁的商品和有pid关系的商品。这两种商品信息修改受到限制。
+        :param shopId:店铺id
+        """
+        return self.__client.call("eleme.product.item.getShopLimitedItems", {"shopId": shop_id})
+
+    def get_test_shop_ids(self):
+        """
+        测试专用，获取测试店铺id数据
+        """
+        return self.__client.call("eleme.product.item.getTestShopIds", {})
+
+    def dy_audit_status_call_back(self, request):
+        """
+        抖音审核回调
+        :param request:回调请求参数
+        """
+        return self.__client.call("eleme.product.dy.dyAuditStatusCallBack", {"request": request})
+
+    def get_shop_commodity_diagnosis_data(self, shop_id):
+        """
+        查询单店铺商品诊断数据
+        :param shopId:店铺ID
+        """
+        return self.__client.call("eleme.product.renovate.getShopCommodityDiagnosisData", {"shopId": shop_id})
+
+    def agree_shop_commodity_diagnosis_problem(self, request):
+        """
+        一键 & 批量优化店铺问题商品详情信息
+        :param request:请求
+        """
+        return self.__client.call("eleme.product.renovate.agreeShopCommodityDiagnosisProblem", {"request": request})
+
     def get_chain_item(self, iid):
         """
         查询连锁总店商品信息
@@ -752,6 +956,41 @@ class ProductService:
         """
         return self.__client.call("eleme.product.chain.item.deleteSku", {"pId": p_id})
 
+    def publish_spu(self, shop_id, spu, is_auto_sync):
+        """
+        发布一个品牌标品
+        :param shopId:店铺id
+        :param spu:品牌标品
+        :param isAutoSync:是否自动同步
+        """
+        return self.__client.call("eleme.product.spu.publishSpu", {"shopId": shop_id, "spu": spu, "isAutoSync": is_auto_sync})
+
+    def delete_spu(self, shop_id, spu_out_code, is_auto_sync):
+        """
+        删除一个品牌标品
+        :param shopId:店铺id
+        :param spuOutCode:spuOutCode
+        :param isAutoSync:是否自动同步
+        """
+        return self.__client.call("eleme.product.spu.deleteSpu", {"shopId": shop_id, "spuOutCode": spu_out_code, "isAutoSync": is_auto_sync})
+
+    def update_spu_sale_status(self, shop_id, spu_out_code, sale_status, is_auto_sync):
+        """
+        修改SPU上下架状态
+        :param shopId:店铺id
+        :param spuOutCode:spuOutCode
+        :param saleStatus:售卖状态,0:上架;1:下架
+        :param isAutoSync:是否自动同步
+        """
+        return self.__client.call("eleme.product.spu.updateSpuSaleStatus", {"shopId": shop_id, "spuOutCode": spu_out_code, "saleStatus": sale_status, "isAutoSync": is_auto_sync})
+
+    def query_spu_by_page(self, query_page):
+        """
+        分页获取店铺下的SPU
+        :param queryPage:分页查询参数
+        """
+        return self.__client.call("eleme.product.spu.querySpuByPage", {"queryPage": query_page})
+
     def upload_image(self, image):
         """
         上传图片，返回图片的hash值
@@ -780,3 +1019,36 @@ class ProductService:
         """
         return self.__client.call("eleme.file.getImageUrl", {"hash": hash})
 
+    def publish_menu(self, shop_id, menu):
+        """
+        发布品牌菜单
+        :param shopId:店铺id
+        :param menu:品牌菜单信息
+        """
+        return self.__client.call("eleme.product.menu.publishMenu", {"shopId": shop_id, "menu": menu})
+
+    def get_menu(self, shop_id, menu_out_code):
+        """
+        获取菜单信息
+        :param shopId:店铺id
+        :param menuOutCode:菜单outCode
+        """
+        return self.__client.call("eleme.product.menu.getMenu", {"shopId": shop_id, "menuOutCode": menu_out_code})
+
+    def sync_menu(self, shop_id, menu_out_code, sync_shop_spus):
+        """
+        同步菜单标品到子门店
+        :param shopId:店铺id
+        :param menuOutCode:菜单outCode
+        :param syncShopSpus:同步店铺id列表
+        """
+        return self.__client.call("eleme.product.menu.syncMenu", {"shopId": shop_id, "menuOutCode": menu_out_code, "syncShopSpus": sync_shop_spus})
+
+    def get_sync_task(self, shop_id, task_id):
+        """
+        获取同步任务详情
+        :param shopId:店铺id
+        :param taskId:任务id
+        """
+        return self.__client.call("eleme.product.menu.getSyncTask", {"shopId": shop_id, "taskId": task_id})
+
